@@ -18,6 +18,7 @@
 #include "favoritelocationmodel.h"
 #include "genericpkpass.h"
 #include "healthcertificatemanager.h"
+#include "journeysectionmodel.h"
 #include "livedatamanager.h"
 #include "localizer.h"
 #include "locationinformation.h"
@@ -149,6 +150,7 @@ void registerApplicationTypes()
     qmlRegisterType<CalendarImportModel>("org.kde.itinerary", 1, 0, "CalendarImportModel");
     qmlRegisterType<CountrySubdivisionModel>("org.kde.itinerary", 1, 0, "CountrySubdivisionModel");
     qmlRegisterType<DocumentsModel>("org.kde.itinerary", 1, 0, "DocumentsModel");
+    qmlRegisterType<JourneySectionModel>("org.kde.itinerary", 1, 0, "JourneySectionModel");
     qmlRegisterType<LocationInformationDelegateController>("org.kde.itinerary", 1, 0, "LocationInformationDelegateController");
     qmlRegisterType<StatisticsModel>("org.kde.itinerary", 1, 0, "StatisticsModel");
     qmlRegisterType<StatisticsTimeRangeModel>("org.kde.itinerary", 1, 0, "StatisticsTimeRangeModel");
