@@ -94,6 +94,9 @@ public:
     /** Provide an icon source for usage in Kirigami.Icon that represents @p journeySection. */
     Q_INVOKABLE QString journeySectionIcon(const KPublicTransport::JourneySection &journeySection) const;
 
+    /** Provide a label that represents @p journeySection. */
+    Q_INVOKABLE QString journeySectionLabel(const KPublicTransport::JourneySection &journeySection) const;
+
     /** Create a KPublicTransport::StopoverRequest for the given KItinerary place. */
     Q_INVOKABLE KPublicTransport::StopoverRequest stopoverRequestForPlace(const QVariant &place, const QDateTime &dt) const;
 
