@@ -6,7 +6,7 @@
 
 #include "timelineelement.h"
 
-#include "locationhelper.h"
+#include "publictransport.h"
 #include "reservationmanager.h"
 #include "timelinemodel.h"
 #include "transfer.h"
@@ -220,44 +220,50 @@ bool TimelineElement::isCanceled() const
     return false;
 }
 
-QString TimelineElement::destinationCountry() const
+static KPublicTransport::Location destinationOfJourney(const KPublicTransport::Journey &jny)
 {
-    if (isReservation()) {
-        const auto res = m_model->m_resMgr->reservation(batchId());
-        return LocationHelper::destinationCountry(res);
+    if (jny.sections().empty()) {
+        return {};
+    }
+    const auto &sections = jny.sections();
+    auto loc = sections.back().arrival().stopPoint();
+
+    if (sections.size() == 1 || sections.back().mode() != KPublicTransport::JourneySection::Walking || sections.back().distance() > 1000) {
+        return loc;
     }
 
-    if (elementType == Transfer) {
-        const auto transfer = m_content.value<::Transfer>();
-        if (transfer.state() == Transfer::Selected) {
-            const auto &sections = transfer.journey().sections();
-            if (!sections.empty()) {
-                return sections.back().arrival().stopPoint().country();
-            }
-        }
+    // the last section is a short walk, its arrival location might not have all the data we have on the previous stop
+    const auto prevLoc = sections[sections.size() - 2].arrival().stopPoint();
+    const auto locName = loc.name();
+
+    // "anonymous" location with the coordinates as name
+    if (std::none_of(locName.begin(), locName.end(), [](QChar c) { return c.isLetter(); }) && !prevLoc.name().isEmpty()) {
+        return prevLoc;
     }
 
-    return {};
+    // propagate address information from the last stop to the final destination
+    if (loc.locality().isEmpty()) { loc.setLocality(prevLoc.locality()); }
+    if (loc.region().isEmpty()) { loc.setRegion(prevLoc.region()); }
+    if (loc.country().isEmpty()) { loc.setLocality(prevLoc.country()); }
+
+    return loc;
 }
 
-KItinerary::GeoCoordinates TimelineElement::destinationCoordinates() const
+QVariant TimelineElement::destination() const
 {
     if (isReservation()) {
         const auto res = m_model->m_resMgr->reservation(batchId());
         if (LocationUtil::isLocationChange(res)) {
-            return LocationUtil::geo(LocationUtil::arrivalLocation(res));
+            return LocationUtil::arrivalLocation(res);
         }
-        return LocationUtil::geo(LocationUtil::location(res));
+        return LocationUtil::location(res);
     }
 
     if (elementType == Transfer) {
         const auto transfer = m_content.value<::Transfer>();
         if (transfer.state() == Transfer::Selected) {
-            const auto &sections = transfer.journey().sections();
-            if (!sections.empty()) {
-                const auto loc = sections.back().arrival().stopPoint();
-                return KItinerary::GeoCoordinates(loc.latitude(), loc.longitude());
-            }
+            const auto loc = destinationOfJourney(transfer.journey());
+            return loc.isEmpty() ? QVariant() : PublicTransport::placeFromLocation<KItinerary::Place>(loc);
         }
     }
 
